@@ -31,4 +31,9 @@ FUNCTION_CHECKER_MSGS = {
         'biszx-domain-func-name',
         settings.MSG_DESCRIPTION
     ),
+    f'C{settings.FUNCTION_MSG_ID}07': (
+        'Inverse function name must be start with _inverse_',
+        'biszx-inverse-func-name',
+        settings.MSG_DESCRIPTION
+    ),
 }
